Gemeinde Adressverwaltung GUI: Klassen-Elemente - Variablen

Gemeinde Adressverwaltung GUI

- frmBottom : Gemeinde.Main
- frmFamilienEinzelheiten : Gemeinde.Main
- frmFamilienListe : Gemeinde.Main
- frmGruppenEinzelheiten : Gemeinde.Main
- frmMain : Gemeinde.Main
- frmNbkAktionen : Gemeinde.Main
- frmNbkFamilien : Gemeinde.Main
- frmNbkHelferlein : Gemeinde.Main
- frmNbkPersonen : Gemeinde.Main
- frmPersonenEinzelheiten : Gemeinde.Main
- frmPersonenListe : Gemeinde.Main
- frmTop : Gemeinde.Main
- frmVersandartenEinzelheiten : Gemeinde.Main
- icons : Gemeinde.Main
- lblTop : Gemeinde.Main
- MenuBar : Gemeinde.Main
- MenuDatei : Gemeinde.Main
- MenuDB : Gemeinde.Main
- MenuHilfe : Gemeinde.Main
- nbkAktionen : Gemeinde.Main
- nbkFamilien : Gemeinde.Main
- nbkHelferlein : Gemeinde.Main
- nbkMain : Gemeinde.Main
- nbkPersonen : Gemeinde.Main
- pndHauptUndFuss : Gemeinde.Main
- style : Gemeinde.Main
- wdgNotify : Gemeinde.Main